pub enum SubscriptionEvent {
Insert,
Update,
Delete,
Reorg,
}Expand description
The kinds of entity change events a subscription may emit.
Variants
Insert
A new entity was inserted.
Update
An existing entity was updated (upsert).
Delete
An entity was deleted.
Reorg
Entities were rolled back due to a chain reorg.